@@ -15,25 +15,45 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Built-in Function} {} [@var{v1},...] =
-## getfields (@var{s}, 'k1',...) = [@var{s}.k1,...]
+## @deftypefn {Built-in Function} {[@var{v1}, @dots{}] =} getfields (@var{s}, 'k1', @dots{})
+##
+## It is equivalent to [@var{s}.k1, @dots{}]
 ## Return selected values from a scalar struct. Provides some
 ## compatibility and some flexibility.
-## @end deftypefn
 ## @seealso{setfields,rmfield,isfield,isstruct,struct}
+## @end deftypefn
 
 function [varargout] = getfields (s, varargin)
 
   if (! all (isfield (s, varargin)))
-    error ("some fields not present");
+    error ("getfields: some fields not present");
   endif
 
   if (all (size (s) <= 1))
     varargout = fields2cell (s, varargin);
   else
-    error ("structure must be scalar or empty");
+    error ("getfields: structure must be scalar or empty");
   endif
 
 endfunction
 
-%!assert (getfields (struct ('key', 'value'), 'key'), 'value');
+%!assert (getfields (struct ("key", "value"), "key"), "value");
+
+%!shared s, x, y, z, oo
+%! s = struct ("hello", 1, "world", 2);
+%!assert (getfields (s, "hello"), s.hello);
+%!assert (getfields (s, "world"), s.world);
+%!
+%! x = 2;
+%! y = 3;
+%! z = "foo";
+%! s = tars (x, y, z);
+%!assert (nthargout (1:3, @getfields, s, "x" , "y" ,"z"), {x y z});
+%!assert (nthargout (1:3, @getfields, s, "x" , "z" ,"z"), {x z z});
+%!
+%!fail ('getfields (s, "foo")')
+
+%!xtest
+%! oo.f0 = 1;
+%! oo = setfield (oo, {1, 2}, "fd", {3}, "b", 6);
+%! assert (getfields (oo, {1, 2}, "fd", {3}, "b"), 6);
