@@ -16,9 +16,9 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} @var{s} = setfields(@var{s},@var{key},@var{value},...)
+## @deftypefn {Function File} {@var{s} =} setfields(@var{s},@var{key},@var{value}, @dots{})
 ## Sets @var{s}.@var{key1} = @var{value1},  @var{s}.@var{key2} = @var{value2}, etc, finally
-## returning s.
+## returning @var{s}.
 ## For some compatibility and flexibility.
 ## @seealso{cmpstruct, fields, rmfield, isstruct, getfields, isfield,struct}
 ## @end deftypefn
@@ -43,5 +43,12 @@ function s = setfields (s, varargin)
   else
     error ("structure must be scalar or empty");
   endif
+endfunction
 
-%!assert (setfields ({}, 'key', 'value'), struct ('key', 'value'));
+%!assert (setfields ({}, "key", "value"), struct ("key", "value"));
+
+%!shared s, t
+%! t = struct ("hello", 1, "world", 2);
+%! s = struct ("foo", "bar", "bye", "ciao");
+%! t = setfields (t, "foo", "bar", "bye", "ciao");
+%!assert ({t.foo t.bye}, {s.foo s.bye})
